@@ -168,7 +168,7 @@ let search_pos_arguments ~pos ~env = function
 
 let search_pos_constructor pcd ~pos ~env =
   if in_loc ~pos pcd.pcd_loc then begin
-    Misc.may (search_pos_type ~pos ~env) pcd.pcd_res;
+    Stdlib.Option.iter (search_pos_type ~pos ~env) pcd.pcd_res;
     search_pos_arguments ~pos ~env pcd.pcd_args
   end
 
@@ -205,10 +205,10 @@ let rec search_pos_signature l ~pos ~env =
   begin fun env pt ->
     let env = match pt.psig_desc with
       Psig_open {popen_override=ovf; popen_expr=id} ->
-        let path, mt = Typetexp.find_module env Location.none id.txt in
+        let path, mt = lookup_module ~loc:Location.none id.txt env in
         begin match open_signature ovf path env with
-          Some env -> env
-        | None -> env
+          Ok env -> env
+        | Error _ -> env
         end
     | sign_item ->
         try add_signature (Typemod.transl_signature env [pt]).sig_type env
@@ -256,8 +256,11 @@ and search_pos_module m ~pos ~env =
       Pmty_ident lid -> add_found_sig (`Modtype, lid.txt) ~env ~loc:m.pmty_loc
     | Pmty_alias lid -> add_found_sig (`Module, lid.txt) ~env ~loc:m.pmty_loc
     | Pmty_signature sg -> search_pos_signature sg ~pos ~env
-    | Pmty_functor (_ , m1, m2) ->
-        Misc.may (search_pos_module ~pos ~env) m1;
+    | Pmty_functor (pm1, m2) ->
+        begin match pm1 with
+        | Unit -> ()
+        | Named (_, m1) -> search_pos_module ~pos ~env m1
+        end;
         search_pos_module m2 ~pos ~env
     | Pmty_with (m, l) ->
         search_pos_module m ~pos ~env;
@@ -348,15 +351,23 @@ let top_widgets = ref []
 
 let dummy_item =
   Sig_modtype (Ident.create_local "dummy",
-               {mtd_type=None; mtd_attributes=[]; mtd_loc=Location.none},
+               {mtd_type=None; mtd_attributes=[]; mtd_loc=Location.none;
+                mtd_uid=Uid.internal_not_actually_unique},
                Exported)
 
+let remove_prefix ~prefix s =
+  let len1 = String.length prefix and len2 = String.length s in
+  if len1 > len2 then None else
+  if String.sub s ~pos:0 ~len:len1 <> prefix then None else
+  Some (String.sub s ~pos:len1 ~len:(len2-len1))
+
 let rec view_signature ?title ?path ?(env = !start_env) ?(detach=false) sign =
   let env =
     match path with None -> env
     | Some path ->
-        match Env.open_signature Fresh path env with None -> env
-        | Some env -> env
+        match Env.open_signature Fresh path env with
+          Ok env -> env
+        | Error _ -> env
   in
   let title =
     match title, path with Some title, _ -> title
@@ -395,10 +406,17 @@ let rec view_signature ?title ?path ?(env = !start_env) ?(detach=false) sign =
         List.iter2 [mw.mw_edit; mw.mw_intf] [".ml"; ".mli"] ~f:
           begin fun button ext ->
             try
+              let path = Env.normalize_module_path None env path in
               let id = head_id path in
+              let name = Ident.name id in
+              let name =
+                match remove_prefix ~prefix:"Stdlib__" name with
+                | None -> name
+                | Some suff -> suff
+              in
               let file =
                 Misc.find_in_path_uncap (Load_path.get_paths ())
-                  ((Ident.name id) ^ ext) in
+                  (name ^ ext) in
               Button.configure button
                 ~command:(fun () -> edit_source ~file ~path ~sign);
               if !repack then Pack.forget [button] else
@@ -478,7 +496,7 @@ and view_module path ~env =
                                        Trec_not, Exported)] ~path ~env
 
 and view_module_id id ~env =
-  let path = lookup_module ~load:true id env in
+  let path, _ = find_module_by_name id env in
   view_module path ~env
 
 and view_type_decl path ~env =
@@ -503,24 +521,24 @@ and view_type_decl path ~env =
       [Sig_type(ident_of_path path ~default:"t", td, Trec_first, Exported)]
 
 and view_type_id li ~env =
-  let path = lookup_type li env in
+  let path, _ = find_type_by_name li env in
   view_type_decl path ~env
 
 and view_class_id li ~env =
-  let path, cl = lookup_class li env in
+  let path, cl = find_class_by_name li env in
   view_signature_item ~path ~env
      [Sig_class(ident_of_path path ~default:"c", cl, Trec_first, Exported);
       dummy_item; dummy_item; dummy_item]
 
 and view_cltype_id li ~env =
-  let path, clt = lookup_cltype li env in
+  let path, clt = find_cltype_by_name li env in
   view_signature_item ~path ~env
      [Sig_class_type(ident_of_path path ~default:"ct", clt, Trec_first,
                      Exported);
       dummy_item; dummy_item]
 
 and view_modtype_id li ~env =
-  let path, td = lookup_modtype li env in
+  let path, td = find_modtype_by_name li env in
   view_signature_item ~path ~env
     [Sig_modtype(ident_of_path path ~default:"S", td, Exported)]
 
@@ -535,7 +553,9 @@ and view_expr_type ?title ?path ?env ?(name="noname") t =
   in
   view_signature ~title ?path ?env
     [Sig_value (id, {val_type = t; val_kind = Val_reg; val_attributes=[];
-                     val_loc = Location.none}, Exported)]
+                     val_loc = Location.none;
+                     val_uid = Uid.internal_not_actually_unique},
+                Exported)]
 
 and view_decl lid ~kind ~env =
   match kind with
@@ -547,10 +567,10 @@ and view_decl lid ~kind ~env =
 and view_decl_menu lid ~kind ~env ~parent =
   let path, kname =
     try match kind with
-      `Type -> lookup_type lid env, "Type"
-    | `Class -> fst (lookup_class lid env), "Class"
-    | `Module -> lookup_module ~load:true lid env, "Module"
-    | `Modtype -> fst (lookup_modtype lid env), "Module type"
+      `Type -> fst (find_type_by_name lid env), "Type"
+    | `Class -> fst (find_class_by_name lid env), "Class"
+    | `Module -> fst (find_module_by_name lid env), "Module"
+    | `Modtype -> fst (find_modtype_by_name lid env), "Module type"
     with Env.Error _ -> raise Not_found
   in
   let menu = Menu.create parent ~tearoff:false in
@@ -633,7 +653,8 @@ let view_type kind ~env =
   | `Class (path, cty) ->
       let cld = { cty_params = []; cty_variance = []; cty_type = cty;
                   cty_path = path; cty_new = None; cty_loc = Location.none;
-                  cty_attributes = []} in
+                  cty_attributes = [];
+                  cty_uid = Uid.internal_not_actually_unique } in
       view_signature_item ~path ~env
         [Sig_class(ident_of_path path ~default:"c", cld, Trec_first,
                    Exported)]
@@ -642,7 +663,8 @@ let view_type kind ~env =
         Mty_signature sign -> view_signature sign ~path ~env
       | modtype ->
           let md =
-	    {md_type = mty; md_attributes = []; md_loc = Location.none} in
+	    {md_type = mty; md_attributes = []; md_loc = Location.none;
+             md_uid = Uid.internal_not_actually_unique} in
           view_signature_item ~path ~env
             [Sig_module(ident_of_path path ~default:"M", Mp_present,
                         md, Trec_not, Exported)]
@@ -764,7 +786,8 @@ and search_pos_class_expr ~pos cl =
         search_pos_class_expr cl ~pos
     | Tcl_apply (cl, el) ->
         search_pos_class_expr cl ~pos;
-        List.iter el ~f:(fun (_, x) -> Misc.may (search_pos_expr ~pos) x)
+        List.iter el
+          ~f:(fun (_, x) -> Stdlib.Option.iter (search_pos_expr ~pos) x)
     | Tcl_let (_, pel, iel, cl) ->
         List.iter pel ~f:
           begin fun {vb_pat=pat; vb_expr=exp} ->
@@ -781,7 +804,8 @@ and search_pos_class_expr ~pos cl =
       ~env:!start_env ~loc:cl.cl_loc
   end
 
-and search_case ~pos {c_lhs; c_guard; c_rhs} =
+and search_case : 'a. pos:_ -> 'a case -> unit =
+  fun ~pos {c_lhs; c_guard; c_rhs} ->
   search_pos_pat c_lhs ~pos ~env:c_rhs.exp_env;
   begin match c_guard with
   | None -> ()
@@ -808,7 +832,8 @@ and search_pos_expr ~pos exp =
   | Texp_function {cases=l; _} ->
       List.iter l ~f:(search_case ~pos)
   | Texp_apply (exp, l) ->
-      List.iter l ~f:(fun (_, x) -> Misc.may (search_pos_expr ~pos) x);
+      List.iter l
+        ~f:(fun (_, x) -> Stdlib.Option.iter (search_pos_expr ~pos) x);
       search_pos_expr exp ~pos
   | Texp_match (exp, l, _) ->
       search_pos_expr exp ~pos;
@@ -877,16 +902,18 @@ and search_pos_expr ~pos exp =
   add_found_str (`Exp(`Expr, exp.exp_type)) ~env:exp.exp_env ~loc:exp.exp_loc
   end
 
-and search_pos_pat ~pos ~env pat =
+and search_pos_pat : type a. pos:_ -> env:_ -> a general_pattern -> unit =
+  fun ~pos ~env pat ->
   if in_loc pat.pat_loc ~pos then begin
   begin match pat.pat_desc with
     Tpat_any -> ()
   | Tpat_var (id, _) ->
       add_found_str (`Exp(`Val (Pident id), pat.pat_type))
         ~env ~loc:pat.pat_loc
-  | Tpat_alias (pat, _, _) -> search_pos_pat pat ~pos ~env
+  | Tpat_alias (pat, _, _)
   | Tpat_lazy pat
   | Tpat_exception pat -> search_pos_pat pat ~pos ~env
+  | Tpat_value pat -> search_pos_pat (pat :> pattern) ~pos ~env
   | Tpat_constant _ ->
       add_found_str (`Exp(`Const, pat.pat_type)) ~env ~loc:pat.pat_loc
   | Tpat_tuple l ->
@@ -914,7 +941,7 @@ and search_pos_module_expr ~pos (m :module_expr) =
         add_found_str (`Module (path, m.mod_type))
           ~env:m.mod_env ~loc:m.mod_loc
     | Tmod_structure str -> search_pos_structure str.str_items ~pos
-    | Tmod_functor (_, _, _, m) -> search_pos_module_expr m ~pos
+    | Tmod_functor (_, m) -> search_pos_module_expr m ~pos
     | Tmod_apply (a, b, _) ->
         search_pos_module_expr a ~pos; search_pos_module_expr b ~pos
     | Tmod_constraint (m, _, _, _) -> search_pos_module_expr m ~pos
@@ -930,7 +957,7 @@ let search_pos_structure ~pos str =
 open Stypes
 
 let search_pos_ti ~pos = function
-    Ti_pat p   -> search_pos_pat ~pos ~env:p.pat_env p
+    Ti_pat (_, p)   -> search_pos_pat ~pos ~env:p.pat_env p
   | Ti_expr e  -> search_pos_expr ~pos e
   | Ti_class c -> search_pos_class_expr ~pos c
   | Ti_mod m   -> search_pos_module_expr ~pos m
